#[non_exhaustive]pub struct CreateNotifyConfigurationInput {
pub display_name: Option<String>,
pub use_case: Option<NotifyConfigurationUseCase>,
pub default_template_id: Option<String>,
pub pool_id: Option<String>,
pub enabled_countries: Option<Vec<String>>,
pub enabled_channels: Option<Vec<NumberCapability>>,
pub deletion_protection_enabled: Option<bool>,
pub client_token: Option<String>,
pub tags: Option<Vec<Tag>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.display_name: Option<String>The display name to associate with the notify configuration.
use_case: Option<NotifyConfigurationUseCase>The use case for the notify configuration.
default_template_id: Option<String>The default template identifier to associate with the notify configuration. If specified, this template is used when sending messages without an explicit template identifier.
pool_id: Option<String>The identifier of the pool to associate with the notify configuration.
enabled_countries: Option<Vec<String>>An array of two-character ISO country codes, in ISO 3166-1 alpha-2 format, that are enabled for the notify configuration.
enabled_channels: Option<Vec<NumberCapability>>An array of channels to enable for the notify configuration. Supported values include SMS and VOICE.
deletion_protection_enabled: Option<bool>By default this is set to false. When set to true the notify configuration can't be deleted. You can change this value using the UpdateNotifyConfiguration action.
client_token: Option<String>Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don't specify a client token, a randomly generated token is used for the request to ensure idempotency.
An array of tags (key and value pairs) associated with the notify configuration.
Implementations
Sourceimpl CreateNotifyConfigurationInput
impl CreateNotifyConfigurationInput
Sourcepub fn display_name(&self) -> Option<&str>
pub fn display_name(&self) -> Option<&str>
The display name to associate with the notify configuration.
Sourcepub fn use_case(&self) -> Option<&NotifyConfigurationUseCase>
pub fn use_case(&self) -> Option<&NotifyConfigurationUseCase>
The use case for the notify configuration.
Sourcepub fn default_template_id(&self) -> Option<&str>
pub fn default_template_id(&self) -> Option<&str>
The default template identifier to associate with the notify configuration. If specified, this template is used when sending messages without an explicit template identifier.
Sourcepub fn pool_id(&self) -> Option<&str>
pub fn pool_id(&self) -> Option<&str>
The identifier of the pool to associate with the notify configuration.
Sourcepub fn enabled_countries(&self) -> &[String]
pub fn enabled_countries(&self) -> &[String]
An array of two-character ISO country codes, in ISO 3166-1 alpha-2 format, that are enabled for the notify configuration.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .enabled_countries.is_none().
Sourcepub fn enabled_channels(&self) -> &[NumberCapability]
pub fn enabled_channels(&self) -> &[NumberCapability]
An array of channels to enable for the notify configuration. Supported values include SMS and VOICE.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .enabled_channels.is_none().
Sourcepub fn deletion_protection_enabled(&self) -> Option<bool>
pub fn deletion_protection_enabled(&self) -> Option<bool>
By default this is set to false. When set to true the notify configuration can't be deleted. You can change this value using the UpdateNotifyConfiguration action.
Sourcepub fn client_token(&self) -> Option<&str>
pub fn client_token(&self) -> Option<&str>
Unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If you don't specify a client token, a randomly generated token is used for the request to ensure idempotency.
An array of tags (key and value pairs) associated with the notify configuration.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().
Sourceimpl CreateNotifyConfigurationInput
impl CreateNotifyConfigurationInput
Sourcepub fn builder() -> CreateNotifyConfigurationInputBuilder
pub fn builder() -> CreateNotifyConfigurationInputBuilder
Creates a new builder-style object to manufacture CreateNotifyConfigurationInput.