#[non_exhaustive]pub struct CreateNotifyConfigurationOutput {Show 15 fields
pub notify_configuration_arn: String,
pub notify_configuration_id: String,
pub display_name: String,
pub use_case: NotifyConfigurationUseCase,
pub default_template_id: Option<String>,
pub pool_id: Option<String>,
pub enabled_countries: Option<Vec<String>>,
pub enabled_channels: Vec<NumberCapability>,
pub tier: NotifyConfigurationTier,
pub tier_upgrade_status: TierUpgradeStatus,
pub status: NotifyConfigurationStatus,
pub rejection_reason: Option<String>,
pub deletion_protection_enabled: bool,
pub tags: Option<Vec<Tag>>,
pub created_timestamp: DateTime,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.notify_configuration_arn: StringThe Amazon Resource Name (ARN) for the notify configuration.
notify_configuration_id: StringThe unique identifier for the notify configuration.
display_name: StringThe display name associated with the notify configuration.
use_case: NotifyConfigurationUseCaseThe use case for the notify configuration.
default_template_id: Option<String>The default template identifier associated with the notify configuration.
pool_id: Option<String>The identifier of the pool associated with the notify configuration.
enabled_countries: Option<Vec<String>>An array of two-character ISO country codes, in ISO 3166-1 alpha-2 format, that are enabled for the notify configuration.
enabled_channels: Vec<NumberCapability>An array of channels enabled for the notify configuration. Supported values include SMS and VOICE.
tier: NotifyConfigurationTierThe tier of the notify configuration.
tier_upgrade_status: TierUpgradeStatusThe tier upgrade status of the notify configuration.
status: NotifyConfigurationStatusThe current status of the notify configuration.
rejection_reason: Option<String>The reason the notify configuration was rejected, if applicable.
deletion_protection_enabled: boolWhen set to true deletion protection is enabled. By default this is set to false.
An array of tags (key and value pairs) associated with the notify configuration.
created_timestamp: DateTimeThe time when the notify configuration was created, in UNIX epoch time format.
Implementations
Sourceimpl CreateNotifyConfigurationOutput
impl CreateNotifyConfigurationOutput
Sourcepub fn notify_configuration_arn(&self) -> &str
pub fn notify_configuration_arn(&self) -> &str
The Amazon Resource Name (ARN) for the notify configuration.
Sourcepub fn notify_configuration_id(&self) -> &str
pub fn notify_configuration_id(&self) -> &str
The unique identifier for the notify configuration.
Sourcepub fn display_name(&self) -> &str
pub fn display_name(&self) -> &str
The display name associated with the notify configuration.
Sourcepub fn use_case(&self) -> &NotifyConfigurationUseCase
pub fn use_case(&self) -> &NotifyConfigurationUseCase
The use case for the notify configuration.
Sourcepub fn default_template_id(&self) -> Option<&str>
pub fn default_template_id(&self) -> Option<&str>
The default template identifier associated with the notify configuration.
Sourcepub fn pool_id(&self) -> Option<&str>
pub fn pool_id(&self) -> Option<&str>
The identifier of the pool associated with the notify configuration.
Sourcepub fn enabled_countries(&self) -> &[String]
pub fn enabled_countries(&self) -> &[String]
An array of two-character ISO country codes, in ISO 3166-1 alpha-2 format, that are enabled for the notify configuration.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .enabled_countries.is_none().
Sourcepub fn enabled_channels(&self) -> &[NumberCapability]
pub fn enabled_channels(&self) -> &[NumberCapability]
An array of channels enabled for the notify configuration. Supported values include SMS and VOICE.
Sourcepub fn tier(&self) -> &NotifyConfigurationTier
pub fn tier(&self) -> &NotifyConfigurationTier
The tier of the notify configuration.
Sourcepub fn tier_upgrade_status(&self) -> &TierUpgradeStatus
pub fn tier_upgrade_status(&self) -> &TierUpgradeStatus
The tier upgrade status of the notify configuration.
Sourcepub fn status(&self) -> &NotifyConfigurationStatus
pub fn status(&self) -> &NotifyConfigurationStatus
The current status of the notify configuration.
Sourcepub fn rejection_reason(&self) -> Option<&str>
pub fn rejection_reason(&self) -> Option<&str>
The reason the notify configuration was rejected, if applicable.
Sourcepub fn deletion_protection_enabled(&self) -> bool
pub fn deletion_protection_enabled(&self) -> bool
When set to true deletion protection is enabled. By default this is set to false.
An array of tags (key and value pairs) associated with the notify configuration.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .tags.is_none().
Sourcepub fn created_timestamp(&self) -> &DateTime
pub fn created_timestamp(&self) -> &DateTime
The time when the notify configuration was created, in UNIX epoch time format.
Sourceimpl CreateNotifyConfigurationOutput
impl CreateNotifyConfigurationOutput
Sourcepub fn builder() -> CreateNotifyConfigurationOutputBuilder
pub fn builder() -> CreateNotifyConfigurationOutputBuilder
Creates a new builder-style object to manufacture CreateNotifyConfigurationOutput.