#[non_exhaustive]pub struct SendNotifyTextMessageInput {
pub notify_configuration_id: Option<String>,
pub destination_phone_number: Option<String>,
pub template_id: Option<String>,
pub template_variables: Option<HashMap<String, String>>,
pub time_to_live: Option<i32>,
pub context: Option<HashMap<String, String>>,
pub configuration_set_name: Option<String>,
pub dry_run: Option<bool>,
pub message_feedback_enabled: Option<bool>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.notify_configuration_id: Option<String>The unique identifier of the notify configuration to use for sending the message. This can be either the NotifyConfigurationId or NotifyConfigurationArn.
destination_phone_number: Option<String>The destination phone number in E.164 format.
template_id: Option<String>The unique identifier of the template to use for the message.
template_variables: Option<HashMap<String, String>>A map of template variable names and their values. All variable values are passed as strings regardless of the declared variable type. For example, pass INTEGER values as "42" and BOOLEAN values as "true" or "false".
time_to_live: Option<i32>How long the text message is valid for, in seconds. By default this is 72 hours.
context: Option<HashMap<String, String>>You can specify custom data in this field. If you do, that data is logged to the event destination.
configuration_set_name: Option<String>The name of the configuration set to use. This can be either the ConfigurationSetName or ConfigurationSetArn.
dry_run: Option<bool>When set to true, the message is checked and validated, but isn't sent to the end recipient.
message_feedback_enabled: Option<bool>Set to true to enable message feedback for the message. When a user receives the message you need to update the message status using PutMessageFeedback.
Implementations
Sourceimpl SendNotifyTextMessageInput
impl SendNotifyTextMessageInput
Sourcepub fn notify_configuration_id(&self) -> Option<&str>
pub fn notify_configuration_id(&self) -> Option<&str>
The unique identifier of the notify configuration to use for sending the message. This can be either the NotifyConfigurationId or NotifyConfigurationArn.
Sourcepub fn destination_phone_number(&self) -> Option<&str>
pub fn destination_phone_number(&self) -> Option<&str>
The destination phone number in E.164 format.
Sourcepub fn template_id(&self) -> Option<&str>
pub fn template_id(&self) -> Option<&str>
The unique identifier of the template to use for the message.
Sourcepub fn template_variables(&self) -> Option<&HashMap<String, String>>
pub fn template_variables(&self) -> Option<&HashMap<String, String>>
A map of template variable names and their values. All variable values are passed as strings regardless of the declared variable type. For example, pass INTEGER values as "42" and BOOLEAN values as "true" or "false".
Sourcepub fn time_to_live(&self) -> Option<i32>
pub fn time_to_live(&self) -> Option<i32>
How long the text message is valid for, in seconds. By default this is 72 hours.
Sourcepub fn context(&self) -> Option<&HashMap<String, String>>
pub fn context(&self) -> Option<&HashMap<String, String>>
You can specify custom data in this field. If you do, that data is logged to the event destination.
Sourcepub fn configuration_set_name(&self) -> Option<&str>
pub fn configuration_set_name(&self) -> Option<&str>
The name of the configuration set to use. This can be either the ConfigurationSetName or ConfigurationSetArn.
Sourcepub fn dry_run(&self) -> Option<bool>
pub fn dry_run(&self) -> Option<bool>
When set to true, the message is checked and validated, but isn't sent to the end recipient.
Sourcepub fn message_feedback_enabled(&self) -> Option<bool>
pub fn message_feedback_enabled(&self) -> Option<bool>
Set to true to enable message feedback for the message. When a user receives the message you need to update the message status using PutMessageFeedback.
Sourceimpl SendNotifyTextMessageInput
impl SendNotifyTextMessageInput
Sourcepub fn builder() -> SendNotifyTextMessageInputBuilder
pub fn builder() -> SendNotifyTextMessageInputBuilder
Creates a new builder-style object to manufacture SendNotifyTextMessageInput.