#[non_exhaustive]pub struct SendNotifyTextMessageOutput {
pub message_id: Option<String>,
pub template_id: Option<String>,
pub resolved_message_body: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message_id: Option<String>The unique identifier for the message.
template_id: Option<String>The unique identifier of the template used for the message.
resolved_message_body: Option<String>The message body after template variable substitution has been applied.
Implementations
Sourceimpl SendNotifyTextMessageOutput
impl SendNotifyTextMessageOutput
Sourcepub fn message_id(&self) -> Option<&str>
pub fn message_id(&self) -> Option<&str>
The unique identifier for the message.
Sourcepub fn template_id(&self) -> Option<&str>
pub fn template_id(&self) -> Option<&str>
The unique identifier of the template used for the message.
Sourcepub fn resolved_message_body(&self) -> Option<&str>
pub fn resolved_message_body(&self) -> Option<&str>
The message body after template variable substitution has been applied.
Sourceimpl SendNotifyTextMessageOutput
impl SendNotifyTextMessageOutput
Sourcepub fn builder() -> SendNotifyTextMessageOutputBuilder
pub fn builder() -> SendNotifyTextMessageOutputBuilder
Creates a new builder-style object to manufacture SendNotifyTextMessageOutput.