#[non_exhaustive]pub struct ConditionalBehavior {
pub rules: Vec<ConditionalRule>,
pub default_behavior: String,
}Expand description
The set of conditional rules that determine a field's resolved requirement based on the values of other fields in the same registration form. Attached to fields whose FieldRequirement is CONDITIONAL.
Evaluation proceeds top-to-bottom through Rules. The first rule whose conditions all evaluate to true wins and its behavior is returned. If no rule matches, the DefaultBehavior is returned.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.rules: Vec<ConditionalRule>An ordered list of conditional rules. Rules are evaluated top-to-bottom and the first rule whose conditions all evaluate to true determines the field's behavior. Rules whose conditions do not all match are skipped and evaluation continues to the next rule.
default_behavior: StringThe field behavior that applies when no conditional rule in Rules matches. Valid values are REQUIRED, OPTIONAL, and DISALLOWED.
Implementations
Sourceimpl ConditionalBehavior
impl ConditionalBehavior
Sourcepub fn rules(&self) -> &[ConditionalRule]
pub fn rules(&self) -> &[ConditionalRule]
An ordered list of conditional rules. Rules are evaluated top-to-bottom and the first rule whose conditions all evaluate to true determines the field's behavior. Rules whose conditions do not all match are skipped and evaluation continues to the next rule.
Sourcepub fn default_behavior(&self) -> &str
pub fn default_behavior(&self) -> &str
The field behavior that applies when no conditional rule in Rules matches. Valid values are REQUIRED, OPTIONAL, and DISALLOWED.
Sourceimpl ConditionalBehavior
impl ConditionalBehavior
Sourcepub fn builder() -> ConditionalBehaviorBuilder
pub fn builder() -> ConditionalBehaviorBuilder
Creates a new builder-style object to manufacture ConditionalBehavior.