#[non_exhaustive]pub struct ConditionalValidation {
pub min_length: Option<i32>,
pub max_length: Option<i32>,
pub pattern: Option<String>,
pub allowed_values: Option<Vec<String>>,
}Expand description
Per-rule validation constraints that override the field's default validation when the containing rule matches. All fields are optional; only the constraints that need to differ from the field's default validation are provided.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.min_length: Option<i32>The minimum length for the field value when this rule applies.
max_length: Option<i32>The maximum length for the field value when this rule applies.
pattern: Option<String>A regular expression that the field value must match when this rule applies.
allowed_values: Option<Vec<String>>The allowed values for a select field when this rule applies. A subset of the field's full option list.
Implementations
Sourceimpl ConditionalValidation
impl ConditionalValidation
Sourcepub fn min_length(&self) -> Option<i32>
pub fn min_length(&self) -> Option<i32>
The minimum length for the field value when this rule applies.
Sourcepub fn max_length(&self) -> Option<i32>
pub fn max_length(&self) -> Option<i32>
The maximum length for the field value when this rule applies.
Sourcepub fn pattern(&self) -> Option<&str>
pub fn pattern(&self) -> Option<&str>
A regular expression that the field value must match when this rule applies.
Sourcepub fn allowed_values(&self) -> &[String]
pub fn allowed_values(&self) -> &[String]
The allowed values for a select field when this rule applies. A subset of the field's full option list.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .allowed_values.is_none().
Sourceimpl ConditionalValidation
impl ConditionalValidation
Sourcepub fn builder() -> ConditionalValidationBuilder
pub fn builder() -> ConditionalValidationBuilder
Creates a new builder-style object to manufacture ConditionalValidation.