#[non_exhaustive]pub struct RcsFallbackConfiguration {
pub channel: RcsFallbackChannel,
pub message_body: Option<String>,
pub media_urls: Option<Vec<String>>,
pub origination_identity: Option<String>,
}Expand description
Configuration for SMS or MMS fallback when RCS delivery fails or the TimeToLive expires without delivery confirmation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.channel: RcsFallbackChannelThe fallback channel to use when RCS delivery fails. Valid values are SMS and MMS. SMS and MMS are mutually exclusive.
message_body: Option<String>The text body of the fallback message. Required for SMS fallback. For MMS fallback, at least one of MessageBody or MediaUrls must be provided.
media_urls: Option<Vec<String>>An array of S3 URIs to media files for MMS fallback. Only valid when Channel is MMS.
origination_identity: Option<String>The origination identity to use for the fallback message. This can be a PhoneNumber, PhoneNumberId, PhoneNumberArn, SenderId, or SenderIdArn. Pool IDs and pool ARNs are not accepted. If not specified and the original message was sent via a pool, the service selects a suitable number from the pool.
Implementations
Sourceimpl RcsFallbackConfiguration
impl RcsFallbackConfiguration
Sourcepub fn channel(&self) -> &RcsFallbackChannel
pub fn channel(&self) -> &RcsFallbackChannel
The fallback channel to use when RCS delivery fails. Valid values are SMS and MMS. SMS and MMS are mutually exclusive.
Sourcepub fn message_body(&self) -> Option<&str>
pub fn message_body(&self) -> Option<&str>
The text body of the fallback message. Required for SMS fallback. For MMS fallback, at least one of MessageBody or MediaUrls must be provided.
Sourcepub fn media_urls(&self) -> &[String]
pub fn media_urls(&self) -> &[String]
An array of S3 URIs to media files for MMS fallback. Only valid when Channel is MMS.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .media_urls.is_none().
Sourcepub fn origination_identity(&self) -> Option<&str>
pub fn origination_identity(&self) -> Option<&str>
The origination identity to use for the fallback message. This can be a PhoneNumber, PhoneNumberId, PhoneNumberArn, SenderId, or SenderIdArn. Pool IDs and pool ARNs are not accepted. If not specified and the original message was sent via a pool, the service selects a suitable number from the pool.
Sourceimpl RcsFallbackConfiguration
impl RcsFallbackConfiguration
Sourcepub fn builder() -> RcsFallbackConfigurationBuilder
pub fn builder() -> RcsFallbackConfigurationBuilder
Creates a new builder-style object to manufacture RcsFallbackConfiguration.