#[non_exhaustive]pub struct RcsFileMessage {
pub file_url: String,
pub thumbnail_url: Option<String>,
}Expand description
A file message containing a media file (image, video, audio, or PDF) with an optional thumbnail.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.file_url: StringThe S3 URI of the media file to send, in the format s3://bucket-name/key. The service downloads the file from your S3 bucket, rehosts it, and generates a presigned URL for the aggregator. Maximum 2000 characters.
thumbnail_url: Option<String>The S3 URI of an optional thumbnail image for the media file, in the format s3://bucket-name/key. Maximum 2000 characters.
Implementations
Sourceimpl RcsFileMessage
impl RcsFileMessage
Sourcepub fn file_url(&self) -> &str
pub fn file_url(&self) -> &str
The S3 URI of the media file to send, in the format s3://bucket-name/key. The service downloads the file from your S3 bucket, rehosts it, and generates a presigned URL for the aggregator. Maximum 2000 characters.
Sourcepub fn thumbnail_url(&self) -> Option<&str>
pub fn thumbnail_url(&self) -> Option<&str>
The S3 URI of an optional thumbnail image for the media file, in the format s3://bucket-name/key. Maximum 2000 characters.
Sourceimpl RcsFileMessage
impl RcsFileMessage
Sourcepub fn builder() -> RcsFileMessageBuilder
pub fn builder() -> RcsFileMessageBuilder
Creates a new builder-style object to manufacture RcsFileMessage.