#[non_exhaustive]pub struct RegistrationTypeDefinition {
pub registration_type: String,
pub supported_associations: Option<Vec<SupportedAssociation>>,
pub display_hints: Option<RegistrationTypeDisplayHints>,
}Expand description
Provides information on the supported registration type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.registration_type: StringThe type of registration form. The list of RegistrationTypes can be found using the DescribeRegistrationTypeDefinitions action.
supported_associations: Option<Vec<SupportedAssociation>>The supported association behavior for the registration type.
display_hints: Option<RegistrationTypeDisplayHints>Provides help information on the registration.
Implementations
Sourceimpl RegistrationTypeDefinition
impl RegistrationTypeDefinition
Sourcepub fn registration_type(&self) -> &str
pub fn registration_type(&self) -> &str
The type of registration form. The list of RegistrationTypes can be found using the DescribeRegistrationTypeDefinitions action.
Sourcepub fn supported_associations(&self) -> &[SupportedAssociation]
pub fn supported_associations(&self) -> &[SupportedAssociation]
The supported association behavior for the registration type.
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .supported_associations.is_none().
Sourcepub fn display_hints(&self) -> Option<&RegistrationTypeDisplayHints>
pub fn display_hints(&self) -> Option<&RegistrationTypeDisplayHints>
Provides help information on the registration.
Sourceimpl RegistrationTypeDefinition
impl RegistrationTypeDefinition
Sourcepub fn builder() -> RegistrationTypeDefinitionBuilder
pub fn builder() -> RegistrationTypeDefinitionBuilder
Creates a new builder-style object to manufacture RegistrationTypeDefinition.