#[non_exhaustive]pub struct RegistrationTypeDisplayHints {
pub title: String,
pub short_description: Option<String>,
pub long_description: Option<String>,
pub documentation_title: Option<String>,
pub documentation_link: Option<String>,
}Expand description
Provides help information on the registration type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.title: StringThe title of the display hint.
short_description: Option<String>A short description of the display hint.
long_description: Option<String>A full description of the display hint.
documentation_title: Option<String>The title of the document the display hint is associated with.
documentation_link: Option<String>The link to the document the display hint is associated with.
Implementations
Sourceimpl RegistrationTypeDisplayHints
impl RegistrationTypeDisplayHints
Sourcepub fn short_description(&self) -> Option<&str>
pub fn short_description(&self) -> Option<&str>
A short description of the display hint.
Sourcepub fn long_description(&self) -> Option<&str>
pub fn long_description(&self) -> Option<&str>
A full description of the display hint.
Sourcepub fn documentation_title(&self) -> Option<&str>
pub fn documentation_title(&self) -> Option<&str>
The title of the document the display hint is associated with.
Sourcepub fn documentation_link(&self) -> Option<&str>
pub fn documentation_link(&self) -> Option<&str>
The link to the document the display hint is associated with.
Sourceimpl RegistrationTypeDisplayHints
impl RegistrationTypeDisplayHints
Sourcepub fn builder() -> RegistrationTypeDisplayHintsBuilder
pub fn builder() -> RegistrationTypeDisplayHintsBuilder
Creates a new builder-style object to manufacture RegistrationTypeDisplayHints.